# vnctp
vnctp is a python binding of CTP for trading China futures market.

Code is from vnpy project, with some adaptation. Only Linux platform is supported.

Use pip install vnctp to install this package.
